"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const codegen_client_1 = require("@graphback/codegen-client");
const codegen_resolvers_1 = require("@graphback/codegen-resolvers");
const codegen_schema_1 = require("@graphback/codegen-schema");
const core_1 = require("@graphback/core");
const runtime_1 = require("@graphback/runtime");
/**
 * GraphQLBackend
 *
 * Automatically generate your database structure resolvers and queries from graphql types.
 * See README for examples
 */
class GraphQLBackendCreator {
    /**
     * @param graphQLSchema string containing graphql types
     * @param config configuration for backend generator
     */
    constructor(schemaContext, config) {
        this.inputContext = core_1.graphQLInputContext.createModelContext(schemaContext.getSchemaText(), config);
    }
    /**
     * Create backend with all related resources
     */
    createBackend(database) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const backend = {};
            const schemaGenerator = new codegen_schema_1.SchemaGenerator(this.inputContext, codegen_schema_1.tsSchemaFormatter);
            backend.schema = schemaGenerator.generate();
            const resolverGenerator = new codegen_resolvers_1.ApolloServiceResolverGenerator(this.inputContext);
            backend.resolvers = resolverGenerator.generate();
            return backend;
        });
    }
    /**
     * Create runtime for backend in form of the schema string and resolve functions
     */
    createRuntime(db, pubSub) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const backend = {
                schema: "",
                resolvers: {}
            };
            const schemaGenerator = new codegen_schema_1.SchemaGenerator(this.inputContext);
            backend.schema = schemaGenerator.generate();
            const defaultProvider = new runtime_1.CRUDService(db, pubSub);
            const resolverGenerator = new runtime_1.LayeredRuntimeResolverGenerator(this.inputContext, defaultProvider);
            backend.resolvers = resolverGenerator.generate();
            return backend;
        });
    }
    createClient() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return codegen_client_1.createClient(this.inputContext);
        });
    }
}
exports.GraphQLBackendCreator = GraphQLBackendCreator;
//# sourceMappingURL=GraphQLBackendCreator.js.map